Module paths

Module paths 

API paths

Constants

API_BASE
CONFIG
SESSIONS_END
SESSIONS_GET
SESSIONS_START
STATUS

Traits

ApiPath
Trait for encrypted types to provide their API path segment. The path format is: /{operation}[_batch]/{type_segment} Examples: /pseudonymize/pseudonym, /rekey_batch/long_attribute, /transcrypt/json

Functions

pseudonymize_batch_path
Generate the pseudonymization batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
pseudonymize_path
Generate the pseudonymization path for a given encrypted type.
rekey_batch_path
Generate the rekey batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
rekey_path
Generate the rekey path for a given encrypted type.
transcrypt_batch_path
Generate the transcrypt batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
transcrypt_path
Generate the transcrypt path for a given encrypted type.