pub fn rekey_batch_path<T: ApiPath + HasStructure>() -> StringExpand description
Generate the rekey batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
pub fn rekey_batch_path<T: ApiPath + HasStructure>() -> StringGenerate the rekey batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.