Pseudonym transcryption
Structs
- Pseudonymization
Batch Request - An API request to transcrypt a batch of encrypted pseudonyms.
- Pseudonymization
Batch Response - Pseudonymization
Request - An API request to transcrypt an encrypted pseudonym.
- Pseudonymization
Response - Rekey
Batch Request - An API request to rekey a batch of encrypted attributes.
- Rekey
Batch Response - Rekey
Request - An API request to rekey an encrypted attribute.
- Rekey
Response - Transcryption
Batch Request - An API request to transcrypt a batch of encrypted data.
- Transcryption
Batch Response - Transcryption
Request - An API request to transcrypt encrypted data.
- Transcryption
Response