API paths
Constants
Traits
- ApiPath
- Trait for encrypted types to provide their API path segment. The path format is: /{operation}[_batch]/{type_segment} Examples: /pseudonymize/pseudonym, /rekey_batch/long_attribute, /transcrypt/json
Functions
- pseudonymize_
batch_ path - Generate the pseudonymization batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
- pseudonymize_
path - Generate the pseudonymization path for a given encrypted type.
- rekey_
batch_ path - Generate the rekey batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
- rekey_
path - Generate the rekey path for a given encrypted type.
- transcrypt_
batch_ path - Generate the transcrypt batch path for a given encrypted type. Requires the type to implement HasStructure for batch validation.
- transcrypt_
path - Generate the transcrypt path for a given encrypted type.